package com.huiju.estateagents.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.huiju.estateagents.base.BaseController;
import com.huiju.estateagents.base.ResponseBean;
import com.huiju.estateagents.entity.TaHousingResources;
import com.huiju.estateagents.service.ITaHousingResourcesService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;

/**
 * <p>
    * 房源表  前端控制器
    * </p>
 *
 * @author jobob
 * @since 2020-02-10
 */
@RestController
@RequestMapping("/api")
public class TaHousingResourcesController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaHousingResourcesController.class);

    @Autowired
    public ITaHousingResourcesService iTaHousingResourcesService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/admin/taHousingResources",method= RequestMethod.GET)
    public ResponseBean taHousingResourcesList(@RequestParam(value = "salesBatchId",required = true) Integer salesBatchId,
                                               @RequestParam(value = "buildingId",required = true) String buildingId,
                                               @RequestParam(value ="pageNumber",defaultValue = "1") Integer pageNumber,
                                               @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize,
                                               HttpServletRequest request){
        ResponseBean responseBean = new ResponseBean();
        try {
            responseBean = iTaHousingResourcesService.selectPageList(salesBatchId, buildingId,pageNumber,pageSize,getOrgId(request));
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taHousingResourcesList -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 保存对象
     * @param taHousingResources 实体对象
     * @return
     */
    @RequestMapping(value="/taHousingResources",method= RequestMethod.POST)
    public ResponseBean taHousingResourcesAdd(@RequestBody TaHousingResources taHousingResources){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iTaHousingResourcesService.save(taHousingResources)){
                responseBean.addSuccess(taHousingResources);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taHousingResourcesAdd -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @ResponseBody
    @RequestMapping(value="/taHousingResources/{id}", method= RequestMethod.DELETE)
    public ResponseBean taHousingResourcesDelete(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            if(iTaHousingResourcesService.removeById(id)){
                responseBean.addSuccess("success");
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taHousingResourcesDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param taHousingResources 实体对象
     * @return
     */
    @RequestMapping(value="/taHousingResources/{id}",method= RequestMethod.PUT)
    public ResponseBean taHousingResourcesUpdate(@PathVariable Integer id,
                                                 @RequestBody TaHousingResources taHousingResources){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iTaHousingResourcesService.updateById(taHousingResources)){
                responseBean.addSuccess(taHousingResources);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taHousingResourcesUpdate -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/taHousingResources/{id}",method= RequestMethod.GET)
    public ResponseBean taHousingResourcesGet(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            responseBean.addSuccess(iTaHousingResourcesService.getById(id));
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taHousingResourcesDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }
}
